import { Facet, StateField } from "@codemirror/state";
import type { EditorView } from "@codemirror/view";
export interface CreateEditOpts {
    prompt: string;
    editorView: EditorView;
    selection: string;
    codeBefore: string;
    codeAfter: string;
    signal?: AbortSignal;
}
export type CompleteFunction = (opts: CreateEditOpts) => Promise<string>;
export interface AiOptions {
    /** Function to generate completions */
    prompt: CompleteFunction;
    /** Called when an error occurs during completion */
    onError?: (error: Error) => void;
    logger?: typeof console;
    /** Called when user accepts an edit */
    onAcceptEdit?: (opts: CreateEditOpts) => void;
    /** Called when user rejects an edit */
    onRejectEdit?: (opts: CreateEditOpts) => void;
    /** Debounce time in ms for input handling */
    inputDebounceTime?: number;
    /** Custom keymaps */
    keymaps?: {
        showInput?: string;
        acceptEdit?: string;
        rejectEdit?: string;
    };
}
/**
 * Default keymap values
 */
export declare const defaultKeymaps: {
    showInput: string;
    acceptEdit: string;
    rejectEdit: string;
};
/**
 * Facet for options
 */
export declare const optionsFacet: Facet<AiOptions, AiOptions>;
export interface InputState {
    show: boolean;
    lineFrom: number;
    lineTo: number;
}
export interface InputValueState {
    shouldFocus: boolean;
    inputValue: string;
}
export interface CompletionState {
    from: number;
    to: number;
    oldCode: string;
    newCode: string;
}
/**
 * State effect to show/hide the tooltip
 */
export declare const showTooltip: import("@codemirror/state").StateEffectType<boolean>;
/**
 * State field to manage the tooltip visibility
 */
export declare const tooltipState: StateField<boolean>;
/**
 * State effect to show/hide the input
 */
export declare const showInput: import("@codemirror/state").StateEffectType<InputState>;
/**
 * State field to manage the input visibility and position
 */
export declare const inputState: StateField<InputState>;
/**
 * State effect to set the input value
 */
export declare const setInputValue: import("@codemirror/state").StateEffectType<string>;
/**
 * State effect to set the input focus
 */
export declare const setInputFocus: import("@codemirror/state").StateEffectType<boolean>;
/**
 * State field for the input focus and value
 */
export declare const inputValueState: StateField<InputValueState>;
/**
 * State effect to show/hide the completion
 */
export declare const showCompletion: import("@codemirror/state").StateEffectType<CompletionState | null>;
/**
 * State field to manage the completion
 */
export declare const completionState: StateField<CompletionState | null>;
/**
 * State effect and field for loading status
 */
export declare const setLoading: import("@codemirror/state").StateEffectType<boolean>;
/**
 * State effect that manages whether the displayed UI
 * shows a loading indicator or not.
 */
export declare const loadingState: StateField<boolean>;
//# sourceMappingURL=state.d.ts.map